/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvControlUnop.h"
#include "HvSignalBiquad.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlSlice.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_VRSVxifj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tj2mdbM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C8oWgEYj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ImP3IhJt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OfLIjEGD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_fYPcmpN6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zs8mdGey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3fGzqowH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o14N2yWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_45jgHX17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NokHf6oi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vfdz8pLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cvtLzKPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_orIjkyo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IO9hm7yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rhecT71M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pvXiaXXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4iRuvgZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kcd2V1Gx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KoEQVNK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QTyjcK57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gdiZnNZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BW7AZtrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RhyamiwA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ccf9L4tC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wLa3A30l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZHcCgmta_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OQIk2Til_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FH5XQm75_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2ZMvOjeS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oFEooZN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0ujQrgiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_V8cDGFbz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mZtIpxDU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eG94Woqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nq7xZMNk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MOI8AJ2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_elZnVABG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hQHq2zLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RDa68EwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HuQYj9kd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b8nMoO3Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ayf47IkJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OjBApNZz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fO69NG8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UdAmskUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5USRRRBj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_op7zr4z6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OayTdSo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AljpmE3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lfFKPirx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WMQGH78z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ChrkoZbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AH4uY65w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fChrgfuk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qGGFGgYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1uuGv8cs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mUWdjOQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jik97J7o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6j4l2aYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DUdhw3wm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6rKddJZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a8fxEeh3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o88qEH0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a5xjF1rn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0O2xduIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UsROJgTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oSpKRysg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e8mQbfXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gUInp9t3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AzHDu28A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QDbZYQH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rp8hiMFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bwXGM4ck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_afmPcaHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0WXhde2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jamBp3MM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fugIE8eV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zGZjvBZI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vR8d0aMR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7fmFctAF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yb9heeLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2bgLQYWg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_YCMN60Ro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nfFonyOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XoBDGN8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TUNMlaDf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_iAsqUAP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_69VABcQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bBoGaeKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SYSYl4eU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_nVyYu10y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VvudDfG5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_V9F17G62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9jBD9utl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7CUXlaFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZDNeZmJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C0JOcMOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hsYVy2EJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pWgU6qjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_McrHFkr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xSN8xcYu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TUXECDCh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MXtHbSLN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G0NFEYuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wH58l8A2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i0qnnJRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DOky93Jz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_l47J0S2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pEVHfgix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TiVc4uLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gkokaLE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1LcgwhHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ie0stFhc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Al5QXfHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t2VOPUA3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CL9TSV2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hr2v0KXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IOOQdXHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RbuGXCok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ITUdmDLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s2G31Sln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2WzwgYX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JGlcESlN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LRZsvDiC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5Rbwe8Cp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Oc0COuRF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jqp6ulIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qEIC3Fym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_h9Fu5BMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZeJruZ0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lUWs2VZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PGQOU9dN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P1Na12tg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tVXvnEQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZH6P7x5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uv9RikWb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GAYDsnnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bbCNuva4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2BeLg4yI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SNE7pNYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V39QW6v1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8ldnXP7Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XRpknhwM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VdldLPeD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kVN8bg8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g0UaEk3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_olqc30ei_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FPamGc0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WEAo4HQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VTaMHuda_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PemcTiFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e1euohLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DAbccFGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fvvaNEjQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_94M6yP35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zhgW8hCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_y7VTRU6q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4LIP8OkY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WRbglXny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D0Iz2DE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EmK32ZzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WbthPpbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AglObP7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HU4Xv9Mb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cLd10wgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jRF9XYSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aGqKg6VB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kDniVtvS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RK4y1aP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BKyVKGZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mnemSePz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9UQX91kz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DyC0iokI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q5eSFC23_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MRioKGHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_US5OtkEr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KU9dn8dO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pVBLGJ4l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iz8oBp9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vKvm0DH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bUA2IXam_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hSajPDRK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UzikVtQW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ccGQ25yY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V6194gNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ne091Drl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vie6Hugb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sLsm4FM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d1pBmt6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TyaAmJQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_59gD8AJU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VmszYf6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KUicy4dY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mMWru7W3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BByOTObX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_46jfH5p5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_67JL0WAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UmvXwKdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PFL8oySn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KxzkiVQR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yovp70on_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fZKpIbSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gb9PVK3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nMKq2JBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T0nKWn4D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uXAz2T3r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GCZSGQ8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OGmhqrJY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FvsV6A7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hp2GO6ET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NXvmbuVl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mkBSViSM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FC8Qc9tm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9YXPoKNU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UOA1x6Do_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lzZsQNBF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VyvvVywk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OASLz5iI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9BWCW1iq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pxwUjZdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0iTfepR7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gtzr7Wke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U4XrJw9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c88l2GuS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WHmnvSwA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BcykTDW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ko9Ai0SC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uasuPSnT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_99OmYwPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LEGLurfL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v3ZxPApM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5JgCARBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_113JyK83_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_I1Q5tKBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YsRjJbdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kJNdu7uv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uR4vBhsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3RsJO6Ct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xxmki35z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Yj7qD9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_deYqrklT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uT3Ojup1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Mp9mcwt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3VTod8t3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VE7OzlS9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bhSMRhLB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KNTGfPOP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kdGCLtix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HkV48NMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MCHxKQ2a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m9h6nipd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uXU2vKxZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fRkShSJI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jwTXosO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z6qdk0hF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SY7OL6pP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JSHNARlY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MTnloMdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MIgmSfa6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XtX5FNYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AwYWK2ZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wo5fwrKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fxx5rYBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AOWtjdLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3mDCCjpM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_44bERmna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nCeOK9Nr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9ExIKvgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5wnIlI8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GYJe5Jsa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qaZSaT16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TAgKWrZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5UY9YTtb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RWEMUgCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B53JFcFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JCjZqY9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1GR8MyPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GF8BUVXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SHgqkz2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IUA6Gej1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_W88O7w3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ced5exKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ngMIux7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N49FpBkf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8G9g9tQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8CSv6jkM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ay5saqN1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ctHONvQ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jMqRQ58K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HRiPzTaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MthpkWB9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6VVZpK0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fLWJxQEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NDX7zxIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sh5nAfVj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5xeiP4Jo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M1nHOuOO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_77EN3vKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AvHs8Hde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vdnsLUdZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wt449GwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WzQRDpSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kiWKv9ID_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iSTnb9vE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rl5tzG34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mKyBcFTs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JnLKJmms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FMUMtnsk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hU7isyzz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TvGYQWS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dmmqdvtk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z2ny31eL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bJonER3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3xaB9tUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jgYQuHP9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_L0Gkqu7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UGdgNRaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V3BHtM3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xxSAnUHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kGURRBYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M8HeRfWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I40qm9hD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Sv0wf2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VfP724ug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DO6NJSKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eGEDo8Gy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1IOiwAxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EV56kkBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S2HWKMMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZQpPQx6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uwmVeH1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_59VgxVIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_07cqO9Ya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kyXGZzhb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2wG723y6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_86rCOWFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HvitJdty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5AZGTEXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8mXybYSf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3xETZXMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8s796l5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xIu2JJOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qcDNJwNm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_50zFpmhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vziyY8DY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WLb41by6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_F8Ky0zVY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_trwaEf6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4VKRQYxB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iVEUF6No_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QNC4rdtL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8ACVPx4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7AUShnAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5mKGH18I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h4aLnLaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xBP2pHhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wuDfFoKa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1ibgi5J0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kvTJVkGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kz69ZZu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Hcp85RKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_epVoGsVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mxx4NoOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2C3pxxZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q39iN9mU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HU66TEje_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cHIOB4LU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lOVAEUdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1jwZRi5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r8uGL84F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bls1AEVb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0UcKXM6U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJbMTgv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jkv7VKix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WdbM2gDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4yYYdGqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qBx5fFqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lAjqF2Vp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MGnVWmq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3WSrwpXD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aWld1KKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7YakBRUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ehh5HYcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ND6jD2Sn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cv3oKaQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_M1rVh4k7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b4tCiBHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Oj1fZf8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5g3mteyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tgVE6oIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_V7gQIv34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NaKSETNg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eIN81sXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RDG4xEbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oY6oRvR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kBWe1ImC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u6bxSfL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rWyKKc3q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YrpjbkaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5HQI8EUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d6QqLHbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vnnJxtUb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R6dxawO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MImwGRft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mQG04Fuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C9VvYxJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iNANFptV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nuy7Lp4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aZceessV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TLmpgX2T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_knFHlJVl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6iSWFzGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rxa4MH0l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kxbhmTp1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PHg2TxrB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rV3X5lR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r6ELv5qQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_z7gq4ReD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2e0ZnDY0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j5itl5SN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hs5Q4mwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kpqcRhc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLYUUHde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D1qEFdUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QOcTenGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UV2T8Ngb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qiY7N5q7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qc7rhuzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q4R1hVhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dDbwKMJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FN1V4BbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P1XXrbhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ggpBFyba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nBEv95nO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3Sh6uMT0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vMRcGkLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ScrrNiN3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tfd9VVUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8Blxm1Xx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eyVj2iJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2Laud1iO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ONK5nQR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yWuXdGRl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vGmYzUhO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fd4dMGXk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EPqBW3k0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kdO8XZpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YQNxSxiu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ymfuh1mW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FVb3xvg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rAmQX40Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yHuDrudD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f1jktdTl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_23F9yhxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lof0G7zR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AhPbt4hC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BfIZZwft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vV2y4KMk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cWSVOAvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gy5C17F4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6l6a9Tyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8ldLFYYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pg3rLGLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EGqJ6jGv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AtIRUAjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Mb1s1gRC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JNFzNJ6v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_P1sh1hmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_z3gMBGJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KuVoD4Un_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GPCEU3zA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xmAb5Aup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B7gIBii1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k6KQhF8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Ri3MEtk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_t1i5mwQd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_85sAtZds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_etN4eg4m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EqayUFqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DRPsvidM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qGB9sozo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_82pyUya1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFQbjGCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3QCOjBKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Z8DjOQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sz4YdT90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4eVyS3lc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m1OLhi5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t5pDU97c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SwnQcDKv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wcupVbBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mJMWklj0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x9fNnyEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZiNalKGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wwkjUsSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9UkiNr7f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ouf4ZGSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_37QL7w60_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_s7UkRCF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FU2Bc3dJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gHU9Fe1i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QxYXrk17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NMM4ONxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gopPCybb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ByNk8j1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RUZ0Rihu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oYRuX3gS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n9X1EX8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CyQZ0ujx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GVZleQCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JRKZhfVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OscQA1Gt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QctP91Vt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lTZq1ZP8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DAn17inx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D3b8eoLe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a1S3kWJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bsnnKzSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_019au6n4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lkdlnO2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CQYwrhe6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FXAJP6eb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wouERnZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_81XVIAQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zOToQOvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LIeQz1sp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5Sg95AFR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TdhSQMUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NuKcc95t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6tLuNbOf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MlHF02Y8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bhyp2YGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ax5q24F6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IDUiHLa6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Ce8XK4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IiKZq2ut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n7WX3E62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9iKHRYxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zCj4uVw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gv6hc0BM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sN9XgxpL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_edmmAldD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZhBKg3Rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EpJ5CXLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1Va8rsuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6051tO7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9Wl6nVcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sNJRbPQt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VIQYOLfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_caCJfhF7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uGBgEQkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c9pQlvcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Hy94dOA2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fDkQXgog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4PY1x8pj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P4Tc3zaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BWXEDdt0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qrjFQRrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_scjZNjM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_64EH7hg9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pc9HGyK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mXPTt3PZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ve5uA9qM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VjBOjlP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4rhxTrAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QQ9KJzC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dppzl3tZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jpVl8BMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7DpOC8pi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lES2WeAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QE0X2f6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_W0EGmjOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OF9ayo8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tXVFYkr8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_txZ1m39e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hUje7aiR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YRzz8aC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1AeITfnf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IVdFwYtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_h9DpUxsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_ij6EbbbE;
  SignalLine sLine_WOAeWzCE;
  SignalLine sLine_CoKPUjqA;
  SignalLine sLine_C4Bo49Y2;
  SignalLine sLine_Bl7jeNtX;
  SignalBiquad sBiquad_s_UQ26xAm3;
  SignalLine sLine_zsnBCe9o;
  SignalLine sLine_e5uTP3UX;
  SignalLine sLine_D3qoCRev;
  SignalLine sLine_5hh2BIvb;
  SignalBiquad sBiquad_s_vg9pVn9S;
  SignalLine sLine_YHfVqPL3;
  SignalLine sLine_LwcDLvtF;
  SignalLine sLine_RKtBoIMf;
  SignalLine sLine_4NYyAP7z;
  SignalLine sLine_BL0mBG6o;
  SignalBiquad sBiquad_s_2iAWqIvW;
  SignalLine sLine_KwFcRNYG;
  SignalLine sLine_twoiYZpZ;
  SignalLine sLine_DfaOx1Xg;
  SignalLine sLine_3GJDOTxG;
  SignalLine sLine_uilWCPnK;
  SignalBiquad sBiquad_s_dNx0hgjR;
  SignalLine sLine_17FDswVT;
  SignalLine sLine_2N2j15K9;
  SignalLine sLine_clGAYN5D;
  SignalLine sLine_8hIf7XNi;
  SignalBiquad sBiquad_s_KgIZg2Hh;
  SignalLine sLine_oBZ4lyCH;
  SignalLine sLine_0q7zyhnb;
  SignalLine sLine_daBbJzlO;
  SignalLine sLine_fQ6GrCOz;
  SignalLine sLine_p9qmRaAs;
  SignalBiquad sBiquad_s_9GPN2RXf;
  ControlVar cVar_VRSVxifj;
  ControlVar cVar_Tj2mdbM7;
  ControlVar cVar_C8oWgEYj;
  ControlVar cVar_ImP3IhJt;
  ControlSlice cSlice_fYPcmpN6;
  ControlVar cVar_zs8mdGey;
  ControlVar cVar_o14N2yWF;
  ControlIf cIf_45jgHX17;
  ControlIf cIf_NokHf6oi;
  ControlBinop cBinop_cvtLzKPr;
  ControlBinop cBinop_orIjkyo9;
  ControlBinop cBinop_pvXiaXXm;
  ControlBinop cBinop_4iRuvgZl;
  ControlBinop cBinop_KoEQVNK6;
  ControlIf cIf_QTyjcK57;
  ControlBinop cBinop_gdiZnNZu;
  ControlBinop cBinop_BW7AZtrQ;
  ControlBinop cBinop_Ccf9L4tC;
  ControlBinop cBinop_wLa3A30l;
  ControlBinop cBinop_ZHcCgmta;
  ControlVar cVar_0ujQrgiH;
  ControlIf cIf_V8cDGFbz;
  ControlIf cIf_mZtIpxDU;
  ControlBinop cBinop_nq7xZMNk;
  ControlBinop cBinop_MOI8AJ2s;
  ControlBinop cBinop_RDa68EwB;
  ControlBinop cBinop_HuQYj9kd;
  ControlBinop cBinop_Ayf47IkJ;
  ControlIf cIf_OjBApNZz;
  ControlBinop cBinop_fO69NG8Q;
  ControlBinop cBinop_UdAmskUk;
  ControlBinop cBinop_op7zr4z6;
  ControlBinop cBinop_OayTdSo6;
  ControlBinop cBinop_AljpmE3d;
  ControlVar cVar_fChrgfuk;
  ControlIf cIf_qGGFGgYL;
  ControlIf cIf_1uuGv8cs;
  ControlBinop cBinop_Jik97J7o;
  ControlBinop cBinop_6j4l2aYA;
  ControlBinop cBinop_a8fxEeh3;
  ControlBinop cBinop_o88qEH0G;
  ControlBinop cBinop_0O2xduIW;
  ControlIf cIf_UsROJgTJ;
  ControlBinop cBinop_oSpKRysg;
  ControlBinop cBinop_e8mQbfXm;
  ControlBinop cBinop_AzHDu28A;
  ControlBinop cBinop_QDbZYQH2;
  ControlBinop cBinop_rp8hiMFi;
  ControlIf cIf_fugIE8eV;
  ControlSlice cSlice_vR8d0aMR;
  ControlVar cVar_7fmFctAF;
  ControlSlice cSlice_YCMN60Ro;
  ControlVar cVar_nfFonyOs;
  ControlSlice cSlice_iAsqUAP4;
  ControlVar cVar_69VABcQV;
  ControlSlice cSlice_nVyYu10y;
  ControlVar cVar_VvudDfG5;
  ControlBinop cBinop_MXtHbSLN;
  ControlBinop cBinop_wH58l8A2;
  ControlBinop cBinop_i0qnnJRu;
  ControlBinop cBinop_pEVHfgix;
  ControlBinop cBinop_TiVc4uLW;
  ControlBinop cBinop_gkokaLE7;
  ControlBinop cBinop_1LcgwhHl;
  ControlBinop cBinop_ie0stFhc;
  ControlVar cVar_Al5QXfHp;
  ControlBinop cBinop_t2VOPUA3;
  ControlBinop cBinop_CL9TSV2c;
  ControlBinop cBinop_Hr2v0KXn;
  ControlBinop cBinop_IOOQdXHf;
  ControlBinop cBinop_RbuGXCok;
  ControlBinop cBinop_ITUdmDLS;
  ControlBinop cBinop_s2G31Sln;
  ControlBinop cBinop_JGlcESlN;
  ControlVar cVar_LRZsvDiC;
  ControlVar cVar_5Rbwe8Cp;
  ControlBinop cBinop_PGQOU9dN;
  ControlBinop cBinop_P1Na12tg;
  ControlBinop cBinop_tVXvnEQe;
  ControlBinop cBinop_Uv9RikWb;
  ControlBinop cBinop_GAYDsnnZ;
  ControlBinop cBinop_bbCNuva4;
  ControlBinop cBinop_2BeLg4yI;
  ControlBinop cBinop_SNE7pNYh;
  ControlBinop cBinop_V39QW6v1;
  ControlBinop cBinop_D0Iz2DE6;
  ControlBinop cBinop_WbthPpbK;
  ControlBinop cBinop_AglObP7J;
  ControlBinop cBinop_jRF9XYSj;
  ControlBinop cBinop_aGqKg6VB;
  ControlBinop cBinop_kDniVtvS;
  ControlBinop cBinop_RK4y1aP2;
  ControlBinop cBinop_BKyVKGZO;
  ControlBinop cBinop_mnemSePz;
  ControlBinop cBinop_9UQX91kz;
  ControlBinop cBinop_Q5eSFC23;
  ControlVar cVar_MRioKGHv;
  ControlVar cVar_US5OtkEr;
  ControlVar cVar_KU9dn8dO;
  ControlBinop cBinop_ccGQ25yY;
  ControlBinop cBinop_V6194gNc;
  ControlBinop cBinop_Ne091Drl;
  ControlBinop cBinop_sLsm4FM2;
  ControlBinop cBinop_d1pBmt6V;
  ControlBinop cBinop_TyaAmJQe;
  ControlBinop cBinop_59gD8AJU;
  ControlBinop cBinop_VmszYf6g;
  ControlBinop cBinop_Hp2GO6ET;
  ControlBinop cBinop_mkBSViSM;
  ControlBinop cBinop_FC8Qc9tm;
  ControlBinop cBinop_lzZsQNBF;
  ControlBinop cBinop_VyvvVywk;
  ControlBinop cBinop_OASLz5iI;
  ControlBinop cBinop_9BWCW1iq;
  ControlBinop cBinop_pxwUjZdF;
  ControlBinop cBinop_Gtzr7Wke;
  ControlBinop cBinop_c88l2GuS;
  ControlBinop cBinop_WHmnvSwA;
  ControlBinop cBinop_Ko9Ai0SC;
  ControlBinop cBinop_uasuPSnT;
  ControlBinop cBinop_99OmYwPl;
  ControlBinop cBinop_v3ZxPApM;
  ControlVar cVar_5JgCARBk;
  ControlVar cVar_113JyK83;
  ControlVar cVar_I1Q5tKBR;
  ControlBinop cBinop_deYqrklT;
  ControlBinop cBinop_uT3Ojup1;
  ControlBinop cBinop_0Mp9mcwt;
  ControlBinop cBinop_VE7OzlS9;
  ControlBinop cBinop_bhSMRhLB;
  ControlBinop cBinop_KNTGfPOP;
  ControlBinop cBinop_kdGCLtix;
  ControlBinop cBinop_HkV48NMD;
  ControlBinop cBinop_MCHxKQ2a;
  ControlBinop cBinop_AwYWK2ZT;
  ControlBinop cBinop_fxx5rYBR;
  ControlBinop cBinop_AOWtjdLt;
  SignalVarf sVarf_YCChHzfB;
  SignalVarf sVarf_QAbPUhLc;
  SignalVarf sVarf_x8WSpEPX;
  ControlSlice cSlice_44bERmna;
  ControlVar cVar_nCeOK9Nr;
  ControlVar cVar_5wnIlI8M;
  ControlIf cIf_GYJe5Jsa;
  ControlIf cIf_qaZSaT16;
  ControlBinop cBinop_5UY9YTtb;
  ControlBinop cBinop_RWEMUgCL;
  ControlBinop cBinop_1GR8MyPh;
  ControlBinop cBinop_GF8BUVXZ;
  ControlBinop cBinop_IUA6Gej1;
  ControlIf cIf_W88O7w3L;
  ControlBinop cBinop_ced5exKd;
  ControlBinop cBinop_ngMIux7O;
  ControlBinop cBinop_8G9g9tQs;
  ControlBinop cBinop_8CSv6jkM;
  ControlBinop cBinop_Ay5saqN1;
  ControlVar cVar_6VVZpK0g;
  ControlIf cIf_fLWJxQEC;
  ControlIf cIf_NDX7zxIg;
  ControlBinop cBinop_5xeiP4Jo;
  ControlBinop cBinop_M1nHOuOO;
  ControlBinop cBinop_vdnsLUdZ;
  ControlBinop cBinop_wt449GwF;
  ControlBinop cBinop_kiWKv9ID;
  ControlIf cIf_iSTnb9vE;
  ControlBinop cBinop_rl5tzG34;
  ControlBinop cBinop_mKyBcFTs;
  ControlBinop cBinop_FMUMtnsk;
  ControlBinop cBinop_hU7isyzz;
  ControlBinop cBinop_TvGYQWS1;
  ControlVar cVar_jgYQuHP9;
  ControlIf cIf_L0Gkqu7V;
  ControlIf cIf_UGdgNRaX;
  ControlBinop cBinop_xxSAnUHg;
  ControlBinop cBinop_kGURRBYk;
  ControlBinop cBinop_5Sv0wf2L;
  ControlBinop cBinop_VfP724ug;
  ControlBinop cBinop_eGEDo8Gy;
  ControlIf cIf_1IOiwAxq;
  ControlBinop cBinop_EV56kkBg;
  ControlBinop cBinop_S2HWKMMg;
  ControlBinop cBinop_uwmVeH1I;
  ControlBinop cBinop_59VgxVIV;
  ControlBinop cBinop_07cqO9Ya;
  ControlIf cIf_5AZGTEXc;
  ControlSlice cSlice_3xETZXMp;
  ControlVar cVar_8s796l5M;
  ControlSlice cSlice_50zFpmhX;
  ControlVar cVar_vziyY8DY;
  ControlSlice cSlice_trwaEf6x;
  ControlVar cVar_4VKRQYxB;
  ControlSlice cSlice_8ACVPx4s;
  ControlVar cVar_7AUShnAV;
  ControlBinop cBinop_2C3pxxZv;
  ControlBinop cBinop_HU66TEje;
  ControlBinop cBinop_cHIOB4LU;
  ControlBinop cBinop_r8uGL84F;
  ControlBinop cBinop_bls1AEVb;
  ControlBinop cBinop_0UcKXM6U;
  ControlBinop cBinop_ZJbMTgv7;
  ControlBinop cBinop_Jkv7VKix;
  ControlVar cVar_WdbM2gDz;
  ControlBinop cBinop_4yYYdGqt;
  ControlBinop cBinop_qBx5fFqe;
  ControlBinop cBinop_lAjqF2Vp;
  ControlBinop cBinop_MGnVWmq6;
  ControlBinop cBinop_3WSrwpXD;
  ControlBinop cBinop_aWld1KKh;
  ControlBinop cBinop_7YakBRUx;
  ControlBinop cBinop_ND6jD2Sn;
  ControlVar cVar_cv3oKaQn;
  ControlVar cVar_M1rVh4k7;
  ControlBinop cBinop_eIN81sXF;
  ControlBinop cBinop_RDG4xEbf;
  ControlBinop cBinop_oY6oRvR1;
  ControlBinop cBinop_u6bxSfL9;
  ControlBinop cBinop_rWyKKc3q;
  ControlBinop cBinop_YrpjbkaW;
  ControlBinop cBinop_5HQI8EUe;
  ControlBinop cBinop_d6QqLHbg;
  ControlBinop cBinop_vnnJxtUb;
  ControlBinop cBinop_hs5Q4mwy;
  ControlBinop cBinop_lLYUUHde;
  ControlBinop cBinop_D1qEFdUx;
  ControlBinop cBinop_qiY7N5q7;
  ControlBinop cBinop_qc7rhuzO;
  ControlBinop cBinop_q4R1hVhg;
  ControlBinop cBinop_dDbwKMJV;
  ControlBinop cBinop_FN1V4BbK;
  ControlBinop cBinop_P1XXrbhp;
  ControlBinop cBinop_ggpBFyba;
  ControlBinop cBinop_3Sh6uMT0;
  ControlVar cVar_vMRcGkLo;
  ControlVar cVar_ScrrNiN3;
  ControlVar cVar_tfd9VVUL;
  ControlBinop cBinop_fd4dMGXk;
  ControlBinop cBinop_EPqBW3k0;
  ControlBinop cBinop_kdO8XZpD;
  ControlBinop cBinop_Ymfuh1mW;
  ControlBinop cBinop_FVb3xvg3;
  ControlBinop cBinop_rAmQX40Q;
  ControlBinop cBinop_yHuDrudD;
  ControlBinop cBinop_f1jktdTl;
  ControlBinop cBinop_GPCEU3zA;
  ControlBinop cBinop_B7gIBii1;
  ControlBinop cBinop_k6KQhF8u;
  ControlBinop cBinop_85sAtZds;
  ControlBinop cBinop_etN4eg4m;
  ControlBinop cBinop_EqayUFqM;
  ControlBinop cBinop_DRPsvidM;
  ControlBinop cBinop_qGB9sozo;
  ControlBinop cBinop_xFQbjGCL;
  ControlBinop cBinop_5Z8DjOQB;
  ControlBinop cBinop_Sz4YdT90;
  ControlBinop cBinop_m1OLhi5l;
  ControlBinop cBinop_t5pDU97c;
  ControlBinop cBinop_SwnQcDKv;
  ControlBinop cBinop_mJMWklj0;
  ControlVar cVar_x9fNnyEv;
  ControlVar cVar_ZiNalKGL;
  ControlVar cVar_wwkjUsSo;
  ControlBinop cBinop_QxYXrk17;
  ControlBinop cBinop_NMM4ONxM;
  ControlBinop cBinop_gopPCybb;
  ControlBinop cBinop_RUZ0Rihu;
  ControlBinop cBinop_oYRuX3gS;
  ControlBinop cBinop_n9X1EX8I;
  ControlBinop cBinop_CyQZ0ujx;
  ControlBinop cBinop_GVZleQCn;
  ControlBinop cBinop_JRKZhfVo;
  ControlBinop cBinop_FXAJP6eb;
  ControlBinop cBinop_81XVIAQF;
  ControlBinop cBinop_zOToQOvU;
  SignalVarf sVarf_Nkl277E1;
  SignalVarf sVarf_9tkPlU0u;
  SignalVarf sVarf_aJoIWrCg;
  SignalVarf sVarf_i430OCqU;
  SignalVarf sVarf_MBjGF4NW;
  SignalVarf sVarf_m9FTE65o;
  SignalVarf sVarf_9vtqv7n4;
  SignalVarf sVarf_Fd7O57i1;
  SignalVarf sVarf_UgXz4kHR;
  ControlVar cVar_LIeQz1sp;
  ControlVar cVar_5Sg95AFR;
  ControlBinop cBinop_ax5q24F6;
  ControlBinop cBinop_IDUiHLa6;
  ControlBinop cBinop_2Ce8XK4k;
  ControlBinop cBinop_n7WX3E62;
  ControlBinop cBinop_9iKHRYxL;
  ControlBinop cBinop_zCj4uVw6;
  ControlBinop cBinop_gv6hc0BM;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
