/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ij6EbbbE);
  numBytes += sLine_init(&sLine_WOAeWzCE);
  numBytes += sLine_init(&sLine_CoKPUjqA);
  numBytes += sLine_init(&sLine_C4Bo49Y2);
  numBytes += sLine_init(&sLine_Bl7jeNtX);
  numBytes += sBiquad_init(&sBiquad_s_UQ26xAm3);
  numBytes += sLine_init(&sLine_zsnBCe9o);
  numBytes += sLine_init(&sLine_e5uTP3UX);
  numBytes += sLine_init(&sLine_D3qoCRev);
  numBytes += sLine_init(&sLine_5hh2BIvb);
  numBytes += sBiquad_init(&sBiquad_s_vg9pVn9S);
  numBytes += sLine_init(&sLine_YHfVqPL3);
  numBytes += sLine_init(&sLine_LwcDLvtF);
  numBytes += sLine_init(&sLine_RKtBoIMf);
  numBytes += sLine_init(&sLine_4NYyAP7z);
  numBytes += sLine_init(&sLine_BL0mBG6o);
  numBytes += sBiquad_init(&sBiquad_s_2iAWqIvW);
  numBytes += sLine_init(&sLine_KwFcRNYG);
  numBytes += sLine_init(&sLine_twoiYZpZ);
  numBytes += sLine_init(&sLine_DfaOx1Xg);
  numBytes += sLine_init(&sLine_3GJDOTxG);
  numBytes += sLine_init(&sLine_uilWCPnK);
  numBytes += sBiquad_init(&sBiquad_s_dNx0hgjR);
  numBytes += sLine_init(&sLine_17FDswVT);
  numBytes += sLine_init(&sLine_2N2j15K9);
  numBytes += sLine_init(&sLine_clGAYN5D);
  numBytes += sLine_init(&sLine_8hIf7XNi);
  numBytes += sBiquad_init(&sBiquad_s_KgIZg2Hh);
  numBytes += sLine_init(&sLine_oBZ4lyCH);
  numBytes += sLine_init(&sLine_0q7zyhnb);
  numBytes += sLine_init(&sLine_daBbJzlO);
  numBytes += sLine_init(&sLine_fQ6GrCOz);
  numBytes += sLine_init(&sLine_p9qmRaAs);
  numBytes += sBiquad_init(&sBiquad_s_9GPN2RXf);
  numBytes += cVar_init_f(&cVar_VRSVxifj, 0.0f);
  numBytes += cVar_init_f(&cVar_Tj2mdbM7, 0.0f);
  numBytes += cVar_init_f(&cVar_C8oWgEYj, 0.0f);
  numBytes += cVar_init_f(&cVar_ImP3IhJt, 0.0f);
  numBytes += cSlice_init(&cSlice_fYPcmpN6, 1, -1);
  numBytes += cVar_init_f(&cVar_zs8mdGey, 1337.0f);
  numBytes += cVar_init_f(&cVar_o14N2yWF, 0.0f);
  numBytes += cIf_init(&cIf_45jgHX17, false);
  numBytes += cIf_init(&cIf_NokHf6oi, false);
  numBytes += cBinop_init(&cBinop_cvtLzKPr, 0.0f); // __pow
  numBytes += cIf_init(&cIf_QTyjcK57, false);
  numBytes += cBinop_init(&cBinop_Ccf9L4tC, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wLa3A30l, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ZHcCgmta, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_0ujQrgiH, 0.0f);
  numBytes += cIf_init(&cIf_V8cDGFbz, false);
  numBytes += cIf_init(&cIf_mZtIpxDU, false);
  numBytes += cBinop_init(&cBinop_nq7xZMNk, 0.0f); // __pow
  numBytes += cIf_init(&cIf_OjBApNZz, false);
  numBytes += cBinop_init(&cBinop_op7zr4z6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_OayTdSo6, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_AljpmE3d, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_fChrgfuk, 0.0f);
  numBytes += cIf_init(&cIf_qGGFGgYL, false);
  numBytes += cIf_init(&cIf_1uuGv8cs, false);
  numBytes += cBinop_init(&cBinop_Jik97J7o, 0.0f); // __pow
  numBytes += cIf_init(&cIf_UsROJgTJ, false);
  numBytes += cBinop_init(&cBinop_AzHDu28A, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_QDbZYQH2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_rp8hiMFi, -15.0f); // __eq
  numBytes += cIf_init(&cIf_fugIE8eV, false);
  numBytes += cSlice_init(&cSlice_vR8d0aMR, 1, -1);
  numBytes += cVar_init_f(&cVar_7fmFctAF, 0.0f);
  numBytes += cSlice_init(&cSlice_YCMN60Ro, 1, -1);
  numBytes += cVar_init_f(&cVar_nfFonyOs, 0.0f);
  numBytes += cSlice_init(&cSlice_iAsqUAP4, 1, -1);
  numBytes += cVar_init_f(&cVar_69VABcQV, 0.0f);
  numBytes += cSlice_init(&cSlice_nVyYu10y, 1, -1);
  numBytes += cVar_init_f(&cVar_VvudDfG5, 0.313f);
  numBytes += cBinop_init(&cBinop_wH58l8A2, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_i0qnnJRu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Al5QXfHp, 0.0f);
  numBytes += cVar_init_f(&cVar_LRZsvDiC, 1337.0f);
  numBytes += cVar_init_f(&cVar_5Rbwe8Cp, 0.3f);
  numBytes += cBinop_init(&cBinop_P1Na12tg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GAYDsnnZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bbCNuva4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2BeLg4yI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SNE7pNYh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V39QW6v1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WbthPpbK, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_AglObP7J, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MRioKGHv, 0.0f);
  numBytes += cVar_init_f(&cVar_US5OtkEr, 1337.0f);
  numBytes += cVar_init_f(&cVar_KU9dn8dO, 0.313f);
  numBytes += cBinop_init(&cBinop_V6194gNc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d1pBmt6V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TyaAmJQe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_59gD8AJU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VmszYf6g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mkBSViSM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FC8Qc9tm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5JgCARBk, 0.0f);
  numBytes += cVar_init_f(&cVar_113JyK83, 1037.0f);
  numBytes += cVar_init_f(&cVar_I1Q5tKBR, 0.4f);
  numBytes += cBinop_init(&cBinop_uT3Ojup1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bhSMRhLB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KNTGfPOP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kdGCLtix, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HkV48NMD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MCHxKQ2a, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_YCChHzfB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QAbPUhLc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_x8WSpEPX, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_44bERmna, 1, -1);
  numBytes += cVar_init_f(&cVar_nCeOK9Nr, 1337.0f);
  numBytes += cVar_init_f(&cVar_5wnIlI8M, 0.0f);
  numBytes += cIf_init(&cIf_GYJe5Jsa, false);
  numBytes += cIf_init(&cIf_qaZSaT16, false);
  numBytes += cBinop_init(&cBinop_5UY9YTtb, 0.0f); // __pow
  numBytes += cIf_init(&cIf_W88O7w3L, false);
  numBytes += cBinop_init(&cBinop_8G9g9tQs, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_8CSv6jkM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Ay5saqN1, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_6VVZpK0g, 0.0f);
  numBytes += cIf_init(&cIf_fLWJxQEC, false);
  numBytes += cIf_init(&cIf_NDX7zxIg, false);
  numBytes += cBinop_init(&cBinop_5xeiP4Jo, 0.0f); // __pow
  numBytes += cIf_init(&cIf_iSTnb9vE, false);
  numBytes += cBinop_init(&cBinop_FMUMtnsk, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_hU7isyzz, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_TvGYQWS1, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_jgYQuHP9, 0.0f);
  numBytes += cIf_init(&cIf_L0Gkqu7V, false);
  numBytes += cIf_init(&cIf_UGdgNRaX, false);
  numBytes += cBinop_init(&cBinop_xxSAnUHg, 0.0f); // __pow
  numBytes += cIf_init(&cIf_1IOiwAxq, false);
  numBytes += cBinop_init(&cBinop_uwmVeH1I, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_59VgxVIV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_07cqO9Ya, -15.0f); // __eq
  numBytes += cIf_init(&cIf_5AZGTEXc, false);
  numBytes += cSlice_init(&cSlice_3xETZXMp, 1, -1);
  numBytes += cVar_init_f(&cVar_8s796l5M, 0.0f);
  numBytes += cSlice_init(&cSlice_50zFpmhX, 1, -1);
  numBytes += cVar_init_f(&cVar_vziyY8DY, 0.0f);
  numBytes += cSlice_init(&cSlice_trwaEf6x, 1, -1);
  numBytes += cVar_init_f(&cVar_4VKRQYxB, 0.0f);
  numBytes += cSlice_init(&cSlice_8ACVPx4s, 1, -1);
  numBytes += cVar_init_f(&cVar_7AUShnAV, 0.313f);
  numBytes += cBinop_init(&cBinop_HU66TEje, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_cHIOB4LU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WdbM2gDz, 0.0f);
  numBytes += cVar_init_f(&cVar_cv3oKaQn, 1337.0f);
  numBytes += cVar_init_f(&cVar_M1rVh4k7, 0.3f);
  numBytes += cBinop_init(&cBinop_RDG4xEbf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rWyKKc3q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YrpjbkaW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5HQI8EUe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d6QqLHbg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vnnJxtUb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lLYUUHde, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_D1qEFdUx, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_vMRcGkLo, 0.0f);
  numBytes += cVar_init_f(&cVar_ScrrNiN3, 1337.0f);
  numBytes += cVar_init_f(&cVar_tfd9VVUL, 0.313f);
  numBytes += cBinop_init(&cBinop_EPqBW3k0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FVb3xvg3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rAmQX40Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yHuDrudD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_f1jktdTl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_B7gIBii1, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_k6KQhF8u, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_x9fNnyEv, 0.0f);
  numBytes += cVar_init_f(&cVar_ZiNalKGL, 1037.0f);
  numBytes += cVar_init_f(&cVar_wwkjUsSo, 0.4f);
  numBytes += cBinop_init(&cBinop_NMM4ONxM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oYRuX3gS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n9X1EX8I, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CyQZ0ujx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GVZleQCn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JRKZhfVo, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Nkl277E1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9tkPlU0u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aJoIWrCg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_i430OCqU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MBjGF4NW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m9FTE65o, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9vtqv7n4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Fd7O57i1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UgXz4kHR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_LIeQz1sp, 5705.6f);
  numBytes += cVar_init_f(&cVar_5Sg95AFR, 313.3f);
  numBytes += cBinop_init(&cBinop_ax5q24F6, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_IDUiHLa6, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_2Ce8XK4k, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sNJRbPQt_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_caCJfhF7_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VIQYOLfs_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h9DpUxsr_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Hy94dOA2_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fDkQXgog_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uGBgEQkG_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c9pQlvcK_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4PY1x8pj_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_scjZNjM1_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qrjFQRrJ_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BWXEDdt0_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mXPTt3PZ_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pc9HGyK5_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_64EH7hg9_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4rhxTrAG_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VjBOjlP7_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ve5uA9qM_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jpVl8BMA_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7DpOC8pi_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QQ9KJzC4_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dppzl3tZ_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lES2WeAY_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OF9ayo8C_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W0EGmjOt_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QE0X2f6S_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hUje7aiR_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_txZ1m39e_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tXVFYkr8_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IVdFwYtV_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1AeITfnf_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YRzz8aC3_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P4Tc3zaQ_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_VRSVxifj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sN9XgxpL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Tj2mdbM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_edmmAldD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_C8oWgEYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZhBKg3Rx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ImP3IhJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EpJ5CXLQ_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MlHF02Y8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bhyp2YGN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6tLuNbOf_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_OfLIjEGD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fYPcmpN6, 0, m, &cSlice_fYPcmpN6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TUNMlaDf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_fYPcmpN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3fGzqowH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3fGzqowH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_zs8mdGey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3fGzqowH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_3fGzqowH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uGBgEQkG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_o14N2yWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gdiZnNZu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_45jgHX17, 0, m, &cIf_45jgHX17_sendMessage);
}

void Heavy_WSTD_EQ::cIf_45jgHX17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BW7AZtrQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_NokHf6oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kcd2V1Gx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_4iRuvgZl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_Vfdz8pLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cvtLzKPr, HV_BINOP_POW, 0, m, &cBinop_cvtLzKPr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cvtLzKPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QTyjcK57, 0, m, &cIf_QTyjcK57_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_orIjkyo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_KoEQVNK6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IO9hm7yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pvXiaXXm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rhecT71M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NokHf6oi, 0, m, &cIf_NokHf6oi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pvXiaXXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NokHf6oi, 1, m, &cIf_NokHf6oi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4iRuvgZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_orIjkyo9_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_kcd2V1Gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_QTyjcK57, 0, m, &cIf_QTyjcK57_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KoEQVNK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cvtLzKPr, HV_BINOP_POW, 1, m, &cBinop_cvtLzKPr_sendMessage);
  cMsg_Vfdz8pLu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_QTyjcK57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YCChHzfB, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_gdiZnNZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_45jgHX17, 1, m, &cIf_45jgHX17_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BW7AZtrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wLa3A30l, HV_BINOP_GREATER_THAN, 1, m, &cBinop_wLa3A30l_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZHcCgmta, HV_BINOP_EQ, 1, m, &cBinop_ZHcCgmta_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_RhyamiwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ccf9L4tC, HV_BINOP_ADD, 0, m, &cBinop_Ccf9L4tC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ccf9L4tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IO9hm7yw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rhecT71M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wLa3A30l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QTyjcK57, 1, m, &cIf_QTyjcK57_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZHcCgmta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQIk2Til_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_OQIk2Til_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YCChHzfB, m);
}

void Heavy_WSTD_EQ::cCast_FH5XQm75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RhyamiwA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_2ZMvOjeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ccf9L4tC, HV_BINOP_ADD, 1, m, &cBinop_Ccf9L4tC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wLa3A30l, HV_BINOP_GREATER_THAN, 0, m, &cBinop_wLa3A30l_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZHcCgmta, HV_BINOP_EQ, 0, m, &cBinop_ZHcCgmta_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oFEooZN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o14N2yWF, 0, m, &cVar_o14N2yWF_sendMessage);
}

void Heavy_WSTD_EQ::cVar_0ujQrgiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fO69NG8Q_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_V8cDGFbz, 0, m, &cIf_V8cDGFbz_sendMessage);
}

void Heavy_WSTD_EQ::cIf_V8cDGFbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UdAmskUk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_mZtIpxDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_b8nMoO3Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_HuQYj9kd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_eG94Woqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nq7xZMNk, HV_BINOP_POW, 0, m, &cBinop_nq7xZMNk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nq7xZMNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OjBApNZz, 0, m, &cIf_OjBApNZz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MOI8AJ2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Ayf47IkJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_elZnVABG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mZtIpxDU, 0, m, &cIf_mZtIpxDU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hQHq2zLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RDa68EwB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RDa68EwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mZtIpxDU, 1, m, &cIf_mZtIpxDU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HuQYj9kd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_MOI8AJ2s_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_b8nMoO3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_OjBApNZz, 0, m, &cIf_OjBApNZz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ayf47IkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nq7xZMNk, HV_BINOP_POW, 1, m, &cBinop_nq7xZMNk_sendMessage);
  cMsg_eG94Woqv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_OjBApNZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AwYWK2ZT_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fxx5rYBR_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_AOWtjdLt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_fO69NG8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V8cDGFbz, 1, m, &cIf_V8cDGFbz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UdAmskUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OayTdSo6, HV_BINOP_GREATER_THAN, 1, m, &cBinop_OayTdSo6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AljpmE3d, HV_BINOP_EQ, 1, m, &cBinop_AljpmE3d_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_5USRRRBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_op7zr4z6, HV_BINOP_ADD, 0, m, &cBinop_op7zr4z6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_op7zr4z6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hQHq2zLA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_elZnVABG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OayTdSo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OjBApNZz, 1, m, &cIf_OjBApNZz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AljpmE3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lfFKPirx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_lfFKPirx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AwYWK2ZT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fxx5rYBR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_AOWtjdLt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WMQGH78z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5USRRRBj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_ChrkoZbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_op7zr4z6, HV_BINOP_ADD, 1, m, &cBinop_op7zr4z6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OayTdSo6, HV_BINOP_GREATER_THAN, 0, m, &cBinop_OayTdSo6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AljpmE3d, HV_BINOP_EQ, 0, m, &cBinop_AljpmE3d_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AH4uY65w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0ujQrgiH, 0, m, &cVar_0ujQrgiH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_fChrgfuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oSpKRysg_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qGGFGgYL, 0, m, &cIf_qGGFGgYL_sendMessage);
}

void Heavy_WSTD_EQ::cIf_qGGFGgYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_e8mQbfXm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_1uuGv8cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_a5xjF1rn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_o88qEH0G_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_mUWdjOQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jik97J7o, HV_BINOP_POW, 0, m, &cBinop_Jik97J7o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Jik97J7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UsROJgTJ, 0, m, &cIf_UsROJgTJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6j4l2aYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0O2xduIW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DUdhw3wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1uuGv8cs, 0, m, &cIf_1uuGv8cs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6rKddJZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_a8fxEeh3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_a8fxEeh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1uuGv8cs, 1, m, &cIf_1uuGv8cs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_o88qEH0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6j4l2aYA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_a5xjF1rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_UsROJgTJ, 0, m, &cIf_UsROJgTJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0O2xduIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jik97J7o, HV_BINOP_POW, 1, m, &cBinop_Jik97J7o_sendMessage);
  cMsg_mUWdjOQK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_UsROJgTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_x8WSpEPX, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_oSpKRysg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qGGFGgYL, 1, m, &cIf_qGGFGgYL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_e8mQbfXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QDbZYQH2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_QDbZYQH2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rp8hiMFi, HV_BINOP_EQ, 1, m, &cBinop_rp8hiMFi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_gUInp9t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AzHDu28A, HV_BINOP_ADD, 0, m, &cBinop_AzHDu28A_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AzHDu28A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6rKddJZW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DUdhw3wm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QDbZYQH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UsROJgTJ, 1, m, &cIf_UsROJgTJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rp8hiMFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bwXGM4ck_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_bwXGM4ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_x8WSpEPX, m);
}

void Heavy_WSTD_EQ::cCast_afmPcaHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AzHDu28A, HV_BINOP_ADD, 1, m, &cBinop_AzHDu28A_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QDbZYQH2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_QDbZYQH2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rp8hiMFi, HV_BINOP_EQ, 0, m, &cBinop_rp8hiMFi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0WXhde2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fChrgfuk, 0, m, &cVar_fChrgfuk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jamBp3MM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gUInp9t3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_fugIE8eV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_QAbPUhLc, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_zGZjvBZI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vR8d0aMR, 0, m, &cSlice_vR8d0aMR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2bgLQYWg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_vR8d0aMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yb9heeLq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yb9heeLq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_7fmFctAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yb9heeLq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_yb9heeLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Hy94dOA2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_2bgLQYWg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YCMN60Ro, 0, m, &cSlice_YCMN60Ro_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OfLIjEGD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_YCMN60Ro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XoBDGN8g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XoBDGN8g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_nfFonyOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XoBDGN8g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_XoBDGN8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4PY1x8pj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_TUNMlaDf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iAsqUAP4, 0, m, &cSlice_iAsqUAP4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_SYSYl4eU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_iAsqUAP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bBoGaeKm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bBoGaeKm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_69VABcQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bBoGaeKm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bBoGaeKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fDkQXgog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_SYSYl4eU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nVyYu10y, 0, m, &cSlice_nVyYu10y_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_nVyYu10y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V9F17G62_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V9F17G62_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_VvudDfG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V9F17G62_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_V9F17G62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c9pQlvcK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_9jBD9utl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ij6EbbbE, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7CUXlaFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WOAeWzCE, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ZDNeZmJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CoKPUjqA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_C0JOcMOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C4Bo49Y2, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hsYVy2EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bl7jeNtX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pWgU6qjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_McrHFkr6_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_McrHFkr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wH58l8A2, HV_BINOP_DIVIDE, 1, m, &cBinop_wH58l8A2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G0NFEYuO_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_xSN8xcYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_MXtHbSLN_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_TUXECDCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_xSN8xcYu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MXtHbSLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wH58l8A2, HV_BINOP_DIVIDE, 0, m, &cBinop_wH58l8A2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_G0NFEYuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TUXECDCh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wH58l8A2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i0qnnJRu, HV_BINOP_MULTIPLY, 1, m, &cBinop_i0qnnJRu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_i0qnnJRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jqp6ulIm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oc0COuRF_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_DOky93Jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qEIC3Fym_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_l47J0S2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h9Fu5BMg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pEVHfgix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_TiVc4uLW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TiVc4uLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i0qnnJRu, HV_BINOP_MULTIPLY, 0, m, &cBinop_i0qnnJRu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gkokaLE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1LcgwhHl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1LcgwhHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lUWs2VZt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ie0stFhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Al5QXfHp, 1, m, &cVar_Al5QXfHp_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Al5QXfHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZH6P7x5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_t2VOPUA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GAYDsnnZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_GAYDsnnZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CL9TSV2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_t2VOPUA3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hr2v0KXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IOOQdXHf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IOOQdXHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bbCNuva4, HV_BINOP_MULTIPLY, 1, m, &cBinop_bbCNuva4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RbuGXCok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2BeLg4yI, HV_BINOP_MULTIPLY, 1, m, &cBinop_2BeLg4yI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ITUdmDLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RbuGXCok_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_s2G31Sln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SNE7pNYh, HV_BINOP_MULTIPLY, 1, m, &cBinop_SNE7pNYh_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2WzwgYX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JGlcESlN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JGlcESlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V39QW6v1, HV_BINOP_MULTIPLY, 1, m, &cBinop_V39QW6v1_sendMessage);
}

void Heavy_WSTD_EQ::cVar_LRZsvDiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VTaMHuda_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_pEVHfgix_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PemcTiFn_sendMessage);
}

void Heavy_WSTD_EQ::cVar_5Rbwe8Cp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gkokaLE7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Oc0COuRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_l47J0S2N_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Jqp6ulIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_DOky93Jz_sendMessage);
}

void Heavy_WSTD_EQ::cSend_qEIC3Fym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BWXEDdt0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_h9Fu5BMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qrjFQRrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ZeJruZ0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_scjZNjM1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_lUWs2VZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PGQOU9dN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PGQOU9dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1Na12tg, HV_BINOP_MULTIPLY, 1, m, &cBinop_P1Na12tg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_P1Na12tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tVXvnEQe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tVXvnEQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZeJruZ0T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ZH6P7x5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Uv9RikWb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Uv9RikWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FPamGc0H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VdldLPeD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g0UaEk3f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_olqc30ei_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WEAo4HQw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kVN8bg8W_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GAYDsnnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9jBD9utl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bbCNuva4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7CUXlaFU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_2BeLg4yI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZDNeZmJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_SNE7pNYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C0JOcMOx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_V39QW6v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hsYVy2EJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_8ldnXP7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LRZsvDiC, 0, m, &cVar_LRZsvDiC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XRpknhwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5Rbwe8Cp, 1, m, &cVar_5Rbwe8Cp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VdldLPeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V39QW6v1, HV_BINOP_MULTIPLY, 0, m, &cBinop_V39QW6v1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kVN8bg8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GAYDsnnZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_GAYDsnnZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_g0UaEk3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SNE7pNYh, HV_BINOP_MULTIPLY, 0, m, &cBinop_SNE7pNYh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_olqc30ei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2BeLg4yI, HV_BINOP_MULTIPLY, 0, m, &cBinop_2BeLg4yI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FPamGc0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_WEAo4HQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bbCNuva4, HV_BINOP_MULTIPLY, 0, m, &cBinop_bbCNuva4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VTaMHuda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5Rbwe8Cp, 0, m, &cVar_5Rbwe8Cp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PemcTiFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Al5QXfHp, 0, m, &cVar_Al5QXfHp_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_e1euohLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zsnBCe9o, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_DAbccFGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e5uTP3UX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_fvvaNEjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D3qoCRev, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_94M6yP35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5hh2BIvb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zhgW8hCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_y7VTRU6q_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_y7VTRU6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WbthPpbK, HV_BINOP_DIVIDE, 1, m, &cBinop_WbthPpbK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EmK32ZzD_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_4LIP8OkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_D0Iz2DE6_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WRbglXny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_4LIP8OkY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_D0Iz2DE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WbthPpbK, HV_BINOP_DIVIDE, 0, m, &cBinop_WbthPpbK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EmK32ZzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WRbglXny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WbthPpbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AglObP7J, HV_BINOP_MULTIPLY, 1, m, &cBinop_AglObP7J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AglObP7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iz8oBp9p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pVBLGJ4l_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_HU4Xv9Mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vKvm0DH0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_cLd10wgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bUA2IXam_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jRF9XYSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_aGqKg6VB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aGqKg6VB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AglObP7J, HV_BINOP_MULTIPLY, 0, m, &cBinop_AglObP7J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kDniVtvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_RK4y1aP2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RK4y1aP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UzikVtQW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_BKyVKGZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TyaAmJQe, HV_BINOP_MULTIPLY, 1, m, &cBinop_TyaAmJQe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mnemSePz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MRioKGHv, 1, m, &cVar_MRioKGHv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9UQX91kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_59gD8AJU, HV_BINOP_MULTIPLY, 1, m, &cBinop_59gD8AJU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DyC0iokI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Q5eSFC23_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Q5eSFC23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VmszYf6g, HV_BINOP_MULTIPLY, 1, m, &cBinop_VmszYf6g_sendMessage);
}

void Heavy_WSTD_EQ::cVar_MRioKGHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vie6Hugb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_US5OtkEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BByOTObX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_jRF9XYSj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_46jfH5p5_sendMessage);
}

void Heavy_WSTD_EQ::cVar_KU9dn8dO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kDniVtvS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pVBLGJ4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_cLd10wgY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iz8oBp9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_HU4Xv9Mb_sendMessage);
}

void Heavy_WSTD_EQ::cSend_vKvm0DH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_64EH7hg9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bUA2IXam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pc9HGyK5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hSajPDRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mXPTt3PZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_UzikVtQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ccGQ25yY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ccGQ25yY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V6194gNc, HV_BINOP_MULTIPLY, 1, m, &cBinop_V6194gNc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V6194gNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ne091Drl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ne091Drl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hSajPDRK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Vie6Hugb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sLsm4FM2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sLsm4FM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PFL8oySn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KxzkiVQR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UmvXwKdQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_67JL0WAe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_d1pBmt6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e1euohLl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_TyaAmJQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DAbccFGS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_59gD8AJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fvvaNEjQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_VmszYf6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_94M6yP35_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_KUicy4dY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_US5OtkEr, 0, m, &cVar_US5OtkEr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mMWru7W3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KU9dn8dO, 1, m, &cVar_KU9dn8dO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BByOTObX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KU9dn8dO, 0, m, &cVar_KU9dn8dO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_46jfH5p5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MRioKGHv, 0, m, &cVar_MRioKGHv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_67JL0WAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1pBmt6V, HV_BINOP_MULTIPLY, 0, m, &cBinop_d1pBmt6V_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UmvXwKdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TyaAmJQe, HV_BINOP_MULTIPLY, 0, m, &cBinop_TyaAmJQe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PFL8oySn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VmszYf6g, HV_BINOP_MULTIPLY, 0, m, &cBinop_VmszYf6g_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KxzkiVQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_59gD8AJU, HV_BINOP_MULTIPLY, 0, m, &cBinop_59gD8AJU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Yovp70on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YHfVqPL3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_fZKpIbSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LwcDLvtF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_gb9PVK3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RKtBoIMf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_nMKq2JBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4NYyAP7z, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_T0nKWn4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BL0mBG6o, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_uXAz2T3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GCZSGQ8L_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_GCZSGQ8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mkBSViSM, HV_BINOP_DIVIDE, 1, m, &cBinop_mkBSViSM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NXvmbuVl_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_OGmhqrJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Hp2GO6ET_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FvsV6A7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_OGmhqrJY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hp2GO6ET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mkBSViSM, HV_BINOP_DIVIDE, 0, m, &cBinop_mkBSViSM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NXvmbuVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FvsV6A7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mkBSViSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FC8Qc9tm, HV_BINOP_MULTIPLY, 1, m, &cBinop_FC8Qc9tm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FC8Qc9tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YsRjJbdo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kJNdu7uv_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_9YXPoKNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uR4vBhsM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_UOA1x6Do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3RsJO6Ct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_lzZsQNBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_VyvvVywk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VyvvVywk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FC8Qc9tm, HV_BINOP_MULTIPLY, 0, m, &cBinop_FC8Qc9tm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OASLz5iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9BWCW1iq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9BWCW1iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Yj7qD9Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pxwUjZdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bhSMRhLB, HV_BINOP_MULTIPLY, 1, m, &cBinop_bhSMRhLB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_0iTfepR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Gtzr7Wke_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Gtzr7Wke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pxwUjZdF_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_U4XrJw9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c88l2GuS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c88l2GuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KNTGfPOP, HV_BINOP_MULTIPLY, 1, m, &cBinop_KNTGfPOP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WHmnvSwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kdGCLtix, HV_BINOP_MULTIPLY, 1, m, &cBinop_kdGCLtix_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_BcykTDW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ko9Ai0SC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ko9Ai0SC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WHmnvSwA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uasuPSnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5JgCARBk, 1, m, &cVar_5JgCARBk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_99OmYwPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HkV48NMD, HV_BINOP_MULTIPLY, 1, m, &cBinop_HkV48NMD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_LEGLurfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_v3ZxPApM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v3ZxPApM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCHxKQ2a, HV_BINOP_MULTIPLY, 1, m, &cBinop_MCHxKQ2a_sendMessage);
}

void Heavy_WSTD_EQ::cVar_5JgCARBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3VTod8t3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_113JyK83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XtX5FNYh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_lzZsQNBF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MIgmSfa6_sendMessage);
}

void Heavy_WSTD_EQ::cVar_I1Q5tKBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_OASLz5iI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YsRjJbdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_9YXPoKNU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kJNdu7uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_UOA1x6Do_sendMessage);
}

void Heavy_WSTD_EQ::cSend_uR4vBhsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ve5uA9qM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_3RsJO6Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VjBOjlP7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_xxmki35z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4rhxTrAG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_4Yj7qD9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_deYqrklT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_deYqrklT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uT3Ojup1, HV_BINOP_MULTIPLY, 1, m, &cBinop_uT3Ojup1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uT3Ojup1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0Mp9mcwt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0Mp9mcwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xxmki35z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_3VTod8t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VE7OzlS9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VE7OzlS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SY7OL6pP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z6qdk0hF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MTnloMdB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JSHNARlY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fRkShSJI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jwTXosO9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bhSMRhLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yovp70on_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KNTGfPOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fZKpIbSP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_kdGCLtix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gb9PVK3j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HkV48NMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nMKq2JBn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_MCHxKQ2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T0nKWn4D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_m9h6nipd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_113JyK83, 0, m, &cVar_113JyK83_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uXU2vKxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I1Q5tKBR, 1, m, &cVar_I1Q5tKBR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fRkShSJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KNTGfPOP, HV_BINOP_MULTIPLY, 0, m, &cBinop_KNTGfPOP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jwTXosO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bhSMRhLB, HV_BINOP_MULTIPLY, 0, m, &cBinop_bhSMRhLB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Z6qdk0hF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCHxKQ2a, HV_BINOP_MULTIPLY, 0, m, &cBinop_MCHxKQ2a_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SY7OL6pP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_JSHNARlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kdGCLtix, HV_BINOP_MULTIPLY, 0, m, &cBinop_kdGCLtix_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MTnloMdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HkV48NMD, HV_BINOP_MULTIPLY, 0, m, &cBinop_HkV48NMD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MIgmSfa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5JgCARBk, 0, m, &cVar_5JgCARBk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XtX5FNYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I1Q5tKBR, 0, m, &cVar_I1Q5tKBR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AwYWK2ZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fugIE8eV, 1, m, &cIf_fugIE8eV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Wo5fwrKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QAbPUhLc, m);
}

void Heavy_WSTD_EQ::cBinop_fxx5rYBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wo5fwrKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_AOWtjdLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fugIE8eV, 0, m, &cIf_fugIE8eV_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_3mDCCjpM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_44bERmna, 0, m, &cSlice_44bERmna_sendMessage);
      break;
    }
    default: {
      cSwitchcase_F8Ky0zVY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_44bERmna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9ExIKvgu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9ExIKvgu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_nCeOK9Nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9ExIKvgu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_9ExIKvgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QQ9KJzC4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_5wnIlI8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ced5exKd_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_GYJe5Jsa, 0, m, &cIf_GYJe5Jsa_sendMessage);
}

void Heavy_WSTD_EQ::cIf_GYJe5Jsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ngMIux7O_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_qaZSaT16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SHgqkz2W_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GF8BUVXZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_TAgKWrZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5UY9YTtb, HV_BINOP_POW, 0, m, &cBinop_5UY9YTtb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5UY9YTtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W88O7w3L, 0, m, &cIf_W88O7w3L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RWEMUgCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IUA6Gej1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_B53JFcFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1GR8MyPh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JCjZqY9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qaZSaT16, 0, m, &cIf_qaZSaT16_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1GR8MyPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qaZSaT16, 1, m, &cIf_qaZSaT16_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GF8BUVXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_RWEMUgCL_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SHgqkz2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_W88O7w3L, 0, m, &cIf_W88O7w3L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IUA6Gej1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5UY9YTtb, HV_BINOP_POW, 1, m, &cBinop_5UY9YTtb_sendMessage);
  cMsg_TAgKWrZ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_W88O7w3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Nkl277E1, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_ced5exKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GYJe5Jsa, 1, m, &cIf_GYJe5Jsa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ngMIux7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8CSv6jkM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8CSv6jkM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ay5saqN1, HV_BINOP_EQ, 1, m, &cBinop_Ay5saqN1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_N49FpBkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8G9g9tQs, HV_BINOP_ADD, 0, m, &cBinop_8G9g9tQs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8G9g9tQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B53JFcFn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JCjZqY9D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8CSv6jkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W88O7w3L, 1, m, &cIf_W88O7w3L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ay5saqN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ctHONvQ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ctHONvQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Nkl277E1, m);
}

void Heavy_WSTD_EQ::cCast_jMqRQ58K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8G9g9tQs, HV_BINOP_ADD, 1, m, &cBinop_8G9g9tQs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8CSv6jkM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_8CSv6jkM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ay5saqN1, HV_BINOP_EQ, 0, m, &cBinop_Ay5saqN1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HRiPzTaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5wnIlI8M, 0, m, &cVar_5wnIlI8M_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MthpkWB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N49FpBkf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_6VVZpK0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rl5tzG34_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_fLWJxQEC, 0, m, &cIf_fLWJxQEC_sendMessage);
}

void Heavy_WSTD_EQ::cIf_fLWJxQEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mKyBcFTs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_NDX7zxIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WzQRDpSo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_wt449GwF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_sh5nAfVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5xeiP4Jo, HV_BINOP_POW, 0, m, &cBinop_5xeiP4Jo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5xeiP4Jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iSTnb9vE, 0, m, &cIf_iSTnb9vE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M1nHOuOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_kiWKv9ID_sendMessage);
}

void Heavy_WSTD_EQ::cCast_77EN3vKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vdnsLUdZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AvHs8Hde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NDX7zxIg, 0, m, &cIf_NDX7zxIg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vdnsLUdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NDX7zxIg, 1, m, &cIf_NDX7zxIg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wt449GwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_M1nHOuOO_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WzQRDpSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_iSTnb9vE, 0, m, &cIf_iSTnb9vE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kiWKv9ID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5xeiP4Jo, HV_BINOP_POW, 1, m, &cBinop_5xeiP4Jo_sendMessage);
  cMsg_sh5nAfVj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_iSTnb9vE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FXAJP6eb_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_81XVIAQF_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_zOToQOvU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_rl5tzG34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fLWJxQEC, 1, m, &cIf_fLWJxQEC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mKyBcFTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hU7isyzz, HV_BINOP_GREATER_THAN, 1, m, &cBinop_hU7isyzz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvGYQWS1, HV_BINOP_EQ, 1, m, &cBinop_TvGYQWS1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JnLKJmms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FMUMtnsk, HV_BINOP_ADD, 0, m, &cBinop_FMUMtnsk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FMUMtnsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_77EN3vKD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AvHs8Hde_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hU7isyzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iSTnb9vE, 1, m, &cIf_iSTnb9vE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TvGYQWS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dmmqdvtk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dmmqdvtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FXAJP6eb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_81XVIAQF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_zOToQOvU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Z2ny31eL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FMUMtnsk, HV_BINOP_ADD, 1, m, &cBinop_FMUMtnsk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hU7isyzz, HV_BINOP_GREATER_THAN, 0, m, &cBinop_hU7isyzz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvGYQWS1, HV_BINOP_EQ, 0, m, &cBinop_TvGYQWS1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bJonER3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JnLKJmms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_3xaB9tUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6VVZpK0g, 0, m, &cVar_6VVZpK0g_sendMessage);
}

void Heavy_WSTD_EQ::cVar_jgYQuHP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EV56kkBg_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_L0Gkqu7V, 0, m, &cIf_L0Gkqu7V_sendMessage);
}

void Heavy_WSTD_EQ::cIf_L0Gkqu7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_S2HWKMMg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_UGdgNRaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_DO6NJSKQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_VfP724ug_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_V3BHtM3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xxSAnUHg, HV_BINOP_POW, 0, m, &cBinop_xxSAnUHg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xxSAnUHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1IOiwAxq, 0, m, &cIf_1IOiwAxq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kGURRBYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_eGEDo8Gy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_M8HeRfWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Sv0wf2L_sendMessage);
}

void Heavy_WSTD_EQ::cCast_I40qm9hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UGdgNRaX, 0, m, &cIf_UGdgNRaX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5Sv0wf2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UGdgNRaX, 1, m, &cIf_UGdgNRaX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VfP724ug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kGURRBYk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DO6NJSKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_1IOiwAxq, 0, m, &cIf_1IOiwAxq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eGEDo8Gy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xxSAnUHg, HV_BINOP_POW, 1, m, &cBinop_xxSAnUHg_sendMessage);
  cMsg_V3BHtM3S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_1IOiwAxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_aJoIWrCg, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_EV56kkBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L0Gkqu7V, 1, m, &cIf_L0Gkqu7V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_S2HWKMMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_59VgxVIV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_59VgxVIV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_07cqO9Ya, HV_BINOP_EQ, 1, m, &cBinop_07cqO9Ya_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZQpPQx6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uwmVeH1I, HV_BINOP_ADD, 0, m, &cBinop_uwmVeH1I_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uwmVeH1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M8HeRfWS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I40qm9hD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_59VgxVIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1IOiwAxq, 1, m, &cIf_1IOiwAxq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_07cqO9Ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kyXGZzhb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_kyXGZzhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aJoIWrCg, m);
}

void Heavy_WSTD_EQ::cCast_2wG723y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jgYQuHP9, 0, m, &cVar_jgYQuHP9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_86rCOWFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uwmVeH1I, HV_BINOP_ADD, 1, m, &cBinop_uwmVeH1I_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_59VgxVIV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_59VgxVIV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_07cqO9Ya, HV_BINOP_EQ, 0, m, &cBinop_07cqO9Ya_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HvitJdty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZQpPQx6A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_5AZGTEXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_9tkPlU0u, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_8mXybYSf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3xETZXMp, 0, m, &cSlice_3xETZXMp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qcDNJwNm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_3xETZXMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xIu2JJOV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xIu2JJOV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_8s796l5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xIu2JJOV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_xIu2JJOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jpVl8BMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_qcDNJwNm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_50zFpmhX, 0, m, &cSlice_50zFpmhX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3mDCCjpM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_50zFpmhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WLb41by6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WLb41by6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_vziyY8DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WLb41by6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_WLb41by6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lES2WeAY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_F8Ky0zVY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_trwaEf6x, 0, m, &cSlice_trwaEf6x_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QNC4rdtL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_trwaEf6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iVEUF6No_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iVEUF6No_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_4VKRQYxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iVEUF6No_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_iVEUF6No_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7DpOC8pi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_QNC4rdtL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8ACVPx4s, 0, m, &cSlice_8ACVPx4s_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_8ACVPx4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5mKGH18I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5mKGH18I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_7AUShnAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5mKGH18I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_5mKGH18I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dppzl3tZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_h4aLnLaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KwFcRNYG, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_xBP2pHhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_twoiYZpZ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wuDfFoKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DfaOx1Xg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_1ibgi5J0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3GJDOTxG, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kvTJVkGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uilWCPnK, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Kz69ZZu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Hcp85RKb_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Hcp85RKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HU66TEje, HV_BINOP_DIVIDE, 1, m, &cBinop_HU66TEje_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q39iN9mU_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_epVoGsVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_2C3pxxZv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mxx4NoOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_epVoGsVg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2C3pxxZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HU66TEje, HV_BINOP_DIVIDE, 0, m, &cBinop_HU66TEje_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Q39iN9mU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mxx4NoOB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HU66TEje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cHIOB4LU, HV_BINOP_MULTIPLY, 1, m, &cBinop_cHIOB4LU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cHIOB4LU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oj1fZf8W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b4tCiBHD_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_lOVAEUdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5g3mteyf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_1jwZRi5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tgVE6oIT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_r8uGL84F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_bls1AEVb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bls1AEVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cHIOB4LU, HV_BINOP_MULTIPLY, 0, m, &cBinop_cHIOB4LU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0UcKXM6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ZJbMTgv7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZJbMTgv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NaKSETNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Jkv7VKix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WdbM2gDz, 1, m, &cVar_WdbM2gDz_sendMessage);
}

void Heavy_WSTD_EQ::cVar_WdbM2gDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kBWe1ImC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4yYYdGqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWyKKc3q, HV_BINOP_MULTIPLY, 1, m, &cBinop_rWyKKc3q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qBx5fFqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4yYYdGqt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lAjqF2Vp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MGnVWmq6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MGnVWmq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YrpjbkaW, HV_BINOP_MULTIPLY, 1, m, &cBinop_YrpjbkaW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3WSrwpXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5HQI8EUe, HV_BINOP_MULTIPLY, 1, m, &cBinop_5HQI8EUe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aWld1KKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3WSrwpXD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7YakBRUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d6QqLHbg, HV_BINOP_MULTIPLY, 1, m, &cBinop_d6QqLHbg_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ehh5HYcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ND6jD2Sn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ND6jD2Sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vnnJxtUb, HV_BINOP_MULTIPLY, 1, m, &cBinop_vnnJxtUb_sendMessage);
}

void Heavy_WSTD_EQ::cVar_cv3oKaQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6iSWFzGw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_r8uGL84F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_knFHlJVl_sendMessage);
}

void Heavy_WSTD_EQ::cVar_M1rVh4k7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_0UcKXM6U_sendMessage);
}

void Heavy_WSTD_EQ::cCast_b4tCiBHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_1jwZRi5i_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Oj1fZf8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_lOVAEUdK_sendMessage);
}

void Heavy_WSTD_EQ::cSend_5g3mteyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QE0X2f6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_tgVE6oIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_W0EGmjOt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_V7gQIv34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OF9ayo8C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_NaKSETNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eIN81sXF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eIN81sXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RDG4xEbf, HV_BINOP_MULTIPLY, 1, m, &cBinop_RDG4xEbf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RDG4xEbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oY6oRvR1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oY6oRvR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V7gQIv34_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_kBWe1ImC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_u6bxSfL9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u6bxSfL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mQG04Fuv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iNANFptV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TLmpgX2T_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aZceessV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C9VvYxJJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nuy7Lp4v_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rWyKKc3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h4aLnLaD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_YrpjbkaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xBP2pHhX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5HQI8EUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wuDfFoKa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_d6QqLHbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1ibgi5J0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vnnJxtUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kvTJVkGs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_R6dxawO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M1rVh4k7, 1, m, &cVar_M1rVh4k7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MImwGRft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cv3oKaQn, 0, m, &cVar_cv3oKaQn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mQG04Fuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_C9VvYxJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YrpjbkaW, HV_BINOP_MULTIPLY, 0, m, &cBinop_YrpjbkaW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iNANFptV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vnnJxtUb, HV_BINOP_MULTIPLY, 0, m, &cBinop_vnnJxtUb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nuy7Lp4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWyKKc3q, HV_BINOP_MULTIPLY, 0, m, &cBinop_rWyKKc3q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aZceessV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5HQI8EUe, HV_BINOP_MULTIPLY, 0, m, &cBinop_5HQI8EUe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TLmpgX2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d6QqLHbg, HV_BINOP_MULTIPLY, 0, m, &cBinop_d6QqLHbg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_knFHlJVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WdbM2gDz, 0, m, &cVar_WdbM2gDz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6iSWFzGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M1rVh4k7, 0, m, &cVar_M1rVh4k7_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_rxa4MH0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_17FDswVT, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kxbhmTp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2N2j15K9, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_PHg2TxrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_clGAYN5D, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_rV3X5lR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8hIf7XNi, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_r6ELv5qQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_z7gq4ReD_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_z7gq4ReD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLYUUHde, HV_BINOP_DIVIDE, 1, m, &cBinop_lLYUUHde_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kpqcRhc6_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_2e0ZnDY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_hs5Q4mwy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_j5itl5SN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_2e0ZnDY0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hs5Q4mwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLYUUHde, HV_BINOP_DIVIDE, 0, m, &cBinop_lLYUUHde_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kpqcRhc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j5itl5SN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_lLYUUHde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D1qEFdUx, HV_BINOP_MULTIPLY, 1, m, &cBinop_D1qEFdUx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_D1qEFdUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Blxm1Xx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eyVj2iJX_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_QOcTenGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2Laud1iO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_UV2T8Ngb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ONK5nQR4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qiY7N5q7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qc7rhuzO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qc7rhuzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D1qEFdUx, HV_BINOP_MULTIPLY, 0, m, &cBinop_D1qEFdUx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q4R1hVhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dDbwKMJV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dDbwKMJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vGmYzUhO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FN1V4BbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rAmQX40Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_rAmQX40Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_P1XXrbhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vMRcGkLo, 1, m, &cVar_vMRcGkLo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ggpBFyba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yHuDrudD, HV_BINOP_MULTIPLY, 1, m, &cBinop_yHuDrudD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_nBEv95nO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3Sh6uMT0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3Sh6uMT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f1jktdTl, HV_BINOP_MULTIPLY, 1, m, &cBinop_f1jktdTl_sendMessage);
}

void Heavy_WSTD_EQ::cVar_vMRcGkLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YQNxSxiu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ScrrNiN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AhPbt4hC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_qiY7N5q7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BfIZZwft_sendMessage);
}

void Heavy_WSTD_EQ::cVar_tfd9VVUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_q4R1hVhg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8Blxm1Xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_QOcTenGI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eyVj2iJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_UV2T8Ngb_sendMessage);
}

void Heavy_WSTD_EQ::cSend_2Laud1iO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tXVFYkr8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ONK5nQR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_txZ1m39e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_yWuXdGRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hUje7aiR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_vGmYzUhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fd4dMGXk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fd4dMGXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EPqBW3k0, HV_BINOP_MULTIPLY, 1, m, &cBinop_EPqBW3k0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EPqBW3k0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kdO8XZpD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kdO8XZpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yWuXdGRl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_YQNxSxiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Ymfuh1mW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ymfuh1mW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vV2y4KMk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gy5C17F4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cWSVOAvn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6l6a9Tyb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FVb3xvg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rxa4MH0l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rAmQX40Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kxbhmTp1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yHuDrudD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PHg2TxrB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_f1jktdTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rV3X5lR6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_23F9yhxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ScrrNiN3, 0, m, &cVar_ScrrNiN3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Lof0G7zR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tfd9VVUL, 1, m, &cVar_tfd9VVUL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AhPbt4hC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tfd9VVUL, 0, m, &cVar_tfd9VVUL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BfIZZwft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vMRcGkLo, 0, m, &cVar_vMRcGkLo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vV2y4KMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f1jktdTl, HV_BINOP_MULTIPLY, 0, m, &cBinop_f1jktdTl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cWSVOAvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rAmQX40Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_rAmQX40Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gy5C17F4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yHuDrudD, HV_BINOP_MULTIPLY, 0, m, &cBinop_yHuDrudD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6l6a9Tyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FVb3xvg3, HV_BINOP_MULTIPLY, 0, m, &cBinop_FVb3xvg3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8ldLFYYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oBZ4lyCH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pg3rLGLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0q7zyhnb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EGqJ6jGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_daBbJzlO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AtIRUAjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fQ6GrCOz, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Mb1s1gRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p9qmRaAs, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JNFzNJ6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_P1sh1hmi_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_P1sh1hmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7gIBii1, HV_BINOP_DIVIDE, 1, m, &cBinop_B7gIBii1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xmAb5Aup_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_z3gMBGJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GPCEU3zA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_KuVoD4Un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_z3gMBGJz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GPCEU3zA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7gIBii1, HV_BINOP_DIVIDE, 0, m, &cBinop_B7gIBii1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xmAb5Aup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KuVoD4Un_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_B7gIBii1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k6KQhF8u, HV_BINOP_MULTIPLY, 1, m, &cBinop_k6KQhF8u_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k6KQhF8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9UkiNr7f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ouf4ZGSo_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Ri3MEtk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_37QL7w60_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_t1i5mwQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s7UkRCF2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_85sAtZds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_etN4eg4m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_etN4eg4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k6KQhF8u, HV_BINOP_MULTIPLY, 0, m, &cBinop_k6KQhF8u_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EqayUFqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_DRPsvidM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DRPsvidM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gHU9Fe1i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qGB9sozo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oYRuX3gS, HV_BINOP_MULTIPLY, 1, m, &cBinop_oYRuX3gS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_82pyUya1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xFQbjGCL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xFQbjGCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qGB9sozo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3QCOjBKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5Z8DjOQB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5Z8DjOQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n9X1EX8I, HV_BINOP_MULTIPLY, 1, m, &cBinop_n9X1EX8I_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Sz4YdT90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CyQZ0ujx, HV_BINOP_MULTIPLY, 1, m, &cBinop_CyQZ0ujx_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_4eVyS3lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_m1OLhi5l_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m1OLhi5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Sz4YdT90_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_t5pDU97c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x9fNnyEv, 1, m, &cVar_x9fNnyEv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SwnQcDKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GVZleQCn, HV_BINOP_MULTIPLY, 1, m, &cBinop_GVZleQCn_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wcupVbBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mJMWklj0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mJMWklj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JRKZhfVo, HV_BINOP_MULTIPLY, 1, m, &cBinop_JRKZhfVo_sendMessage);
}

void Heavy_WSTD_EQ::cVar_x9fNnyEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0ByNk8j1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ZiNalKGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CQYwrhe6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_85sAtZds_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lkdlnO2Z_sendMessage);
}

void Heavy_WSTD_EQ::cVar_wwkjUsSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_EqayUFqM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9UkiNr7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Ri3MEtk8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ouf4ZGSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_t1i5mwQd_sendMessage);
}

void Heavy_WSTD_EQ::cSend_37QL7w60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YRzz8aC3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_s7UkRCF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1AeITfnf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_FU2Bc3dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IVdFwYtV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_gHU9Fe1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QxYXrk17_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QxYXrk17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NMM4ONxM, HV_BINOP_MULTIPLY, 1, m, &cBinop_NMM4ONxM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NMM4ONxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gopPCybb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gopPCybb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FU2Bc3dJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_0ByNk8j1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RUZ0Rihu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RUZ0Rihu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_019au6n4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DAn17inx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lTZq1ZP8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a1S3kWJP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D3b8eoLe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bsnnKzSp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oYRuX3gS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ldLFYYY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_n9X1EX8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pg3rLGLJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_CyQZ0ujx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EGqJ6jGv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GVZleQCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AtIRUAjz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JRKZhfVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mb1s1gRC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_OscQA1Gt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZiNalKGL, 0, m, &cVar_ZiNalKGL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QctP91Vt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wwkjUsSo, 1, m, &cVar_wwkjUsSo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lTZq1ZP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GVZleQCn, HV_BINOP_MULTIPLY, 0, m, &cBinop_GVZleQCn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DAn17inx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JRKZhfVo, HV_BINOP_MULTIPLY, 0, m, &cBinop_JRKZhfVo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_D3b8eoLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n9X1EX8I, HV_BINOP_MULTIPLY, 0, m, &cBinop_n9X1EX8I_sendMessage);
}

void Heavy_WSTD_EQ::cCast_a1S3kWJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CyQZ0ujx, HV_BINOP_MULTIPLY, 0, m, &cBinop_CyQZ0ujx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bsnnKzSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oYRuX3gS, HV_BINOP_MULTIPLY, 0, m, &cBinop_oYRuX3gS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_019au6n4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_lkdlnO2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x9fNnyEv, 0, m, &cVar_x9fNnyEv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CQYwrhe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wwkjUsSo, 0, m, &cVar_wwkjUsSo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FXAJP6eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5AZGTEXc, 1, m, &cIf_5AZGTEXc_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wouERnZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9tkPlU0u, m);
}

void Heavy_WSTD_EQ::cBinop_81XVIAQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wouERnZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zOToQOvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5AZGTEXc, 0, m, &cIf_5AZGTEXc_sendMessage);
}

void Heavy_WSTD_EQ::cVar_LIeQz1sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IDUiHLa6, HV_BINOP_DIVIDE, 0, m, &cBinop_IDUiHLa6_sendMessage);
}

void Heavy_WSTD_EQ::cVar_5Sg95AFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ax5q24F6, HV_BINOP_DIVIDE, 1, m, &cBinop_ax5q24F6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IDUiHLa6, HV_BINOP_DIVIDE, 1, m, &cBinop_IDUiHLa6_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_TdhSQMUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Ce8XK4k, HV_BINOP_DIVIDE, 0, m, &cBinop_2Ce8XK4k_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_NuKcc95t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Ce8XK4k, HV_BINOP_DIVIDE, 1, m, &cBinop_2Ce8XK4k_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6tLuNbOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ax5q24F6, HV_BINOP_DIVIDE, 0, m, &cBinop_ax5q24F6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MlHF02Y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5Sg95AFR, 0, m, &cVar_5Sg95AFR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bhyp2YGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LIeQz1sp, 0, m, &cVar_LIeQz1sp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ax5q24F6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_TdhSQMUf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IDUiHLa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_NuKcc95t_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2Ce8XK4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_9iKHRYxL_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_IiKZq2ut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_gv6hc0BM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_n7WX3E62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_zCj4uVw6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9iKHRYxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n7WX3E62_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zCj4uVw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_IiKZq2ut_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gv6hc0BM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Va8rsuF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_sN9XgxpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zGZjvBZI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_8mXybYSf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_edmmAldD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zGZjvBZI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_8mXybYSf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ZhBKg3Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zGZjvBZI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_8mXybYSf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EpJ5CXLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zGZjvBZI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_8mXybYSf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_1Va8rsuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zGZjvBZI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_8mXybYSf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_6051tO7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ImP3IhJt, 0, m, &cVar_ImP3IhJt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9Wl6nVcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_VRSVxifj, 0, m, &cVar_VRSVxifj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Tj2mdbM7, 0, m, &cVar_Tj2mdbM7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C8oWgEYj, 0, m, &cVar_C8oWgEYj_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_sNJRbPQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VRSVxifj, 0, m, &cVar_VRSVxifj_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_VIQYOLfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tj2mdbM7, 0, m, &cVar_Tj2mdbM7_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_caCJfhF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C8oWgEYj, 0, m, &cVar_C8oWgEYj_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_uGBgEQkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_US5OtkEr, 0, m, &cVar_US5OtkEr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_c9pQlvcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mMWru7W3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KUicy4dY_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Hy94dOA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oFEooZN2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ZMvOjeS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FH5XQm75_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_fDkQXgog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0WXhde2h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_afmPcaHC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jamBp3MM_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_4PY1x8pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AH4uY65w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ChrkoZbe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WMQGH78z_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_P4Tc3zaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pWgU6qjU_sendMessage(_c, 0, m);
  cMsg_zhgW8hCl_sendMessage(_c, 0, m);
  cMsg_uXAz2T3r_sendMessage(_c, 0, m);
  cMsg_Kz69ZZu7_sendMessage(_c, 0, m);
  cMsg_r6ELv5qQ_sendMessage(_c, 0, m);
  cMsg_JNFzNJ6v_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LRZsvDiC, 0, m, &cVar_LRZsvDiC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_US5OtkEr, 0, m, &cVar_US5OtkEr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_113JyK83, 0, m, &cVar_113JyK83_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cv3oKaQn, 0, m, &cVar_cv3oKaQn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ScrrNiN3, 0, m, &cVar_ScrrNiN3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZiNalKGL, 0, m, &cVar_ZiNalKGL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zs8mdGey, 0, m, &cVar_zs8mdGey_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o14N2yWF, 0, m, &cVar_o14N2yWF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0ujQrgiH, 0, m, &cVar_0ujQrgiH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fChrgfuk, 0, m, &cVar_fChrgfuk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7fmFctAF, 0, m, &cVar_7fmFctAF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nfFonyOs, 0, m, &cVar_nfFonyOs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_69VABcQV, 0, m, &cVar_69VABcQV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VvudDfG5, 0, m, &cVar_VvudDfG5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nCeOK9Nr, 0, m, &cVar_nCeOK9Nr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5wnIlI8M, 0, m, &cVar_5wnIlI8M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6VVZpK0g, 0, m, &cVar_6VVZpK0g_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jgYQuHP9, 0, m, &cVar_jgYQuHP9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8s796l5M, 0, m, &cVar_8s796l5M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vziyY8DY, 0, m, &cVar_vziyY8DY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4VKRQYxB, 0, m, &cVar_4VKRQYxB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7AUShnAV, 0, m, &cVar_7AUShnAV_sendMessage);
  cMsg_9Wl6nVcr_sendMessage(_c, 0, m);
  cMsg_6051tO7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_BWXEDdt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1Na12tg, HV_BINOP_MULTIPLY, 0, m, &cBinop_P1Na12tg_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qrjFQRrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CL9TSV2c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Hr2v0KXn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ITUdmDLS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_s2G31Sln_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_scjZNjM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ie0stFhc_sendMessage);
  cMsg_2WzwgYX6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_64EH7hg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V6194gNc, HV_BINOP_MULTIPLY, 0, m, &cBinop_V6194gNc_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_pc9HGyK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_9UQX91kz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_mXPTt3PZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1pBmt6V, HV_BINOP_MULTIPLY, 1, m, &cBinop_d1pBmt6V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BKyVKGZO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mnemSePz_sendMessage);
  cMsg_DyC0iokI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_Ve5uA9qM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uT3Ojup1, HV_BINOP_MULTIPLY, 0, m, &cBinop_uT3Ojup1_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_VjBOjlP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0iTfepR7_sendMessage(_c, 0, m);
  cMsg_U4XrJw9G_sendMessage(_c, 0, m);
  cMsg_BcykTDW6_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_99OmYwPl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_4rhxTrAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uasuPSnT_sendMessage);
  cMsg_LEGLurfL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_QQ9KJzC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ScrrNiN3, 0, m, &cVar_ScrrNiN3_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_dppzl3tZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lof0G7zR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_23F9yhxG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_jpVl8BMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HRiPzTaB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jMqRQ58K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MthpkWB9_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_7DpOC8pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2wG723y6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_86rCOWFw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HvitJdty_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_lES2WeAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3xaB9tUI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z2ny31eL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bJonER3c_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_QE0X2f6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RDG4xEbf, HV_BINOP_MULTIPLY, 0, m, &cBinop_RDG4xEbf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_W0EGmjOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qBx5fFqe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lAjqF2Vp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aWld1KKh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7YakBRUx_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_OF9ayo8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Jkv7VKix_sendMessage);
  cMsg_ehh5HYcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_tXVFYkr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EPqBW3k0, HV_BINOP_MULTIPLY, 0, m, &cBinop_EPqBW3k0_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_txZ1m39e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ggpBFyba_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_hUje7aiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FVb3xvg3, HV_BINOP_MULTIPLY, 1, m, &cBinop_FVb3xvg3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FN1V4BbK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_P1XXrbhp_sendMessage);
  cMsg_nBEv95nO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_YRzz8aC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NMM4ONxM, HV_BINOP_MULTIPLY, 0, m, &cBinop_NMM4ONxM_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_1AeITfnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_82pyUya1_sendMessage(_c, 0, m);
  cMsg_3QCOjBKl_sendMessage(_c, 0, m);
  cMsg_4eVyS3lc_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_SwnQcDKv_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_IVdFwYtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_t5pDU97c_sendMessage);
  cMsg_wcupVbBl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_h9DpUxsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ImP3IhJt, 0, m, &cVar_ImP3IhJt_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_i430OCqU, VOf(Bf0));
    __hv_varread_f(&sVarf_MBjGF4NW, VOf(Bf1));
    __hv_varread_f(&sVarf_m9FTE65o, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_9vtqv7n4, VOf(Bf0));
    __hv_varread_f(&sVarf_Fd7O57i1, VOf(Bf1));
    __hv_varread_f(&sVarf_UgXz4kHR, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_ij6EbbbE, VOf(Bf0));
    __hv_line_f(&sLine_WOAeWzCE, VOf(Bf1));
    __hv_line_f(&sLine_CoKPUjqA, VOf(Bf4));
    __hv_line_f(&sLine_C4Bo49Y2, VOf(Bf5));
    __hv_line_f(&sLine_Bl7jeNtX, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_UQ26xAm3, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_YCChHzfB, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_zsnBCe9o, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_e5uTP3UX, VOf(Bf1));
    __hv_line_f(&sLine_D3qoCRev, VOf(Bf0));
    __hv_line_f(&sLine_5hh2BIvb, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_vg9pVn9S, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_QAbPUhLc, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_YHfVqPL3, VOf(Bf7));
    __hv_line_f(&sLine_LwcDLvtF, VOf(Bf1));
    __hv_line_f(&sLine_RKtBoIMf, VOf(Bf4));
    __hv_line_f(&sLine_4NYyAP7z, VOf(Bf6));
    __hv_line_f(&sLine_BL0mBG6o, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_2iAWqIvW, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_x8WSpEPX, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_i430OCqU, VIf(Bf5));
    __hv_varwrite_f(&sVarf_MBjGF4NW, VIf(Bf0));
    __hv_varwrite_f(&sVarf_m9FTE65o, VIf(Bf6));
    __hv_line_f(&sLine_KwFcRNYG, VOf(Bf6));
    __hv_line_f(&sLine_twoiYZpZ, VOf(Bf0));
    __hv_line_f(&sLine_DfaOx1Xg, VOf(Bf5));
    __hv_line_f(&sLine_3GJDOTxG, VOf(Bf8));
    __hv_line_f(&sLine_uilWCPnK, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_dNx0hgjR, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Nkl277E1, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_17FDswVT, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_2N2j15K9, VOf(Bf0));
    __hv_line_f(&sLine_clGAYN5D, VOf(Bf6));
    __hv_line_f(&sLine_8hIf7XNi, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_KgIZg2Hh, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_9tkPlU0u, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_oBZ4lyCH, VOf(Bf1));
    __hv_line_f(&sLine_0q7zyhnb, VOf(Bf0));
    __hv_line_f(&sLine_daBbJzlO, VOf(Bf5));
    __hv_line_f(&sLine_fQ6GrCOz, VOf(Bf4));
    __hv_line_f(&sLine_p9qmRaAs, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_9GPN2RXf, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_aJoIWrCg, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_9vtqv7n4, VIf(Bf8));
    __hv_varwrite_f(&sVarf_Fd7O57i1, VIf(Bf6));
    __hv_varwrite_f(&sVarf_UgXz4kHR, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
